@@ -4,3 +4,7 @@ This module declares commands and responses defined in part 102
 ("General requirements - Control gear") and parts 2xx (lamp specific
 extensions and control gear specific features).
 """
+import dali.gear.general
+import dali.gear.emergency
+import dali.gear.incandescent
+import dali.gear.led  # noqa: F401
